@@ -156,6 +156,8 @@
 #include <stan/math/prim/prob/inv_gamma_log.hpp>
 #include <stan/math/prim/prob/inv_gamma_lpdf.hpp>
 #include <stan/math/prim/prob/inv_gamma_rng.hpp>
+#include <stan/math/prim/prob/inv_wishart_cholesky_lpdf.hpp>
+#include <stan/math/prim/prob/inv_wishart_cholesky_rng.hpp>
 #include <stan/math/prim/prob/inv_wishart_log.hpp>
 #include <stan/math/prim/prob/inv_wishart_lpdf.hpp>
 #include <stan/math/prim/prob/inv_wishart_rng.hpp>
@@ -175,6 +177,10 @@
 #include <stan/math/prim/prob/logistic_log.hpp>
 #include <stan/math/prim/prob/logistic_lpdf.hpp>
 #include <stan/math/prim/prob/logistic_rng.hpp>
+#include <stan/math/prim/prob/loglogistic_cdf.hpp>
+#include <stan/math/prim/prob/loglogistic_log.hpp>
+#include <stan/math/prim/prob/loglogistic_lpdf.hpp>
+#include <stan/math/prim/prob/loglogistic_rng.hpp>
 #include <stan/math/prim/prob/lognormal_ccdf_log.hpp>
 #include <stan/math/prim/prob/lognormal_cdf.hpp>
 #include <stan/math/prim/prob/lognormal_cdf_log.hpp>
@@ -199,6 +205,8 @@
 #include <stan/math/prim/prob/multi_normal_prec_lpdf.hpp>
 #include <stan/math/prim/prob/multi_normal_prec_rng.hpp>
 #include <stan/math/prim/prob/multi_normal_rng.hpp>
+#include <stan/math/prim/prob/multi_student_t_cholesky_lpdf.hpp>
+#include <stan/math/prim/prob/multi_student_t_cholesky_rng.hpp>
 #include <stan/math/prim/prob/multi_student_t_log.hpp>
 #include <stan/math/prim/prob/multi_student_t_lpdf.hpp>
 #include <stan/math/prim/prob/multi_student_t_rng.hpp>
@@ -264,8 +272,12 @@
 #include <stan/math/prim/prob/pareto_type_2_log.hpp>
 #include <stan/math/prim/prob/pareto_type_2_lpdf.hpp>
 #include <stan/math/prim/prob/pareto_type_2_rng.hpp>
+#include <stan/math/prim/prob/poisson_binomial_ccdf_log.hpp>
+#include <stan/math/prim/prob/poisson_binomial_cdf.hpp>
+#include <stan/math/prim/prob/poisson_binomial_cdf_log.hpp>
 #include <stan/math/prim/prob/poisson_binomial_lccdf.hpp>
 #include <stan/math/prim/prob/poisson_binomial_lcdf.hpp>
+#include <stan/math/prim/prob/poisson_binomial_log.hpp>
 #include <stan/math/prim/prob/poisson_binomial_lpmf.hpp>
 #include <stan/math/prim/prob/poisson_binomial_rng.hpp>
 #include <stan/math/prim/prob/poisson_ccdf_log.hpp>
@@ -297,6 +309,14 @@
 #include <stan/math/prim/prob/scaled_inv_chi_square_log.hpp>
 #include <stan/math/prim/prob/scaled_inv_chi_square_lpdf.hpp>
 #include <stan/math/prim/prob/scaled_inv_chi_square_rng.hpp>
+#include <stan/math/prim/prob/skew_double_exponential_ccdf_log.hpp>
+#include <stan/math/prim/prob/skew_double_exponential_cdf.hpp>
+#include <stan/math/prim/prob/skew_double_exponential_cdf_log.hpp>
+#include <stan/math/prim/prob/skew_double_exponential_lpdf.hpp>
+#include <stan/math/prim/prob/skew_double_exponential_lcdf.hpp>
+#include <stan/math/prim/prob/skew_double_exponential_lccdf.hpp>
+#include <stan/math/prim/prob/skew_double_exponential_log.hpp>
+#include <stan/math/prim/prob/skew_double_exponential_rng.hpp>
 #include <stan/math/prim/prob/skew_normal_ccdf_log.hpp>
 #include <stan/math/prim/prob/skew_normal_cdf.hpp>
 #include <stan/math/prim/prob/skew_normal_cdf_log.hpp>
@@ -311,6 +331,7 @@
 #include <stan/math/prim/prob/std_normal_lcdf.hpp>
 #include <stan/math/prim/prob/std_normal_lccdf.hpp>
 #include <stan/math/prim/prob/std_normal_log.hpp>
+#include <stan/math/prim/prob/std_normal_log_qf.hpp>
 #include <stan/math/prim/prob/std_normal_lpdf.hpp>
 #include <stan/math/prim/prob/std_normal_rng.hpp>
 #include <stan/math/prim/prob/student_t_ccdf_log.hpp>
@@ -332,7 +353,9 @@
 #include <stan/math/prim/prob/von_mises_log.hpp>
 #include <stan/math/prim/prob/von_mises_lpdf.hpp>
 #include <stan/math/prim/prob/von_mises_rng.hpp>
+#include <stan/math/prim/prob/von_mises_ccdf_log.hpp>
 #include <stan/math/prim/prob/von_mises_cdf.hpp>
+#include <stan/math/prim/prob/von_mises_cdf_log.hpp>
 #include <stan/math/prim/prob/von_mises_lcdf.hpp>
 #include <stan/math/prim/prob/von_mises_lccdf.hpp>
 #include <stan/math/prim/prob/weibull_ccdf_log.hpp>
@@ -345,6 +368,8 @@
 #include <stan/math/prim/prob/weibull_rng.hpp>
 #include <stan/math/prim/prob/wiener_log.hpp>
 #include <stan/math/prim/prob/wiener_lpdf.hpp>
+#include <stan/math/prim/prob/wishart_cholesky_lpdf.hpp>
+#include <stan/math/prim/prob/wishart_cholesky_rng.hpp>
 #include <stan/math/prim/prob/wishart_log.hpp>
 #include <stan/math/prim/prob/wishart_lpdf.hpp>
 #include <stan/math/prim/prob/wishart_rng.hpp>
